TencentCloudChatVoteDataContent class

Constructors

TencentCloudChatVoteDataContent({required List<TencentCloudChatVoteDataOptoin> option_list, String? original_msg_id, int? original_msg_seq})
TencentCloudChatVoteDataContent.fromJson(Map<String, dynamic> json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option_list ↔ List<TencentCloudChatVoteDataOptoin>
getter/setter pair
original_msg_id ↔ String?
getter/setter pair
original_msg_seq ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited