TencentCloudChatVoteLogic class

Constructors

TencentCloudChatVoteLogic({required dynamic message})

Properties

groupInfos ↔ Map<String, V2TimGroupMemberFullInfo>
getter/setter pair
groupMemberCount ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isClose ↔ bool
getter/setter pair
isFold ↔ bool
getter/setter pair
isFormSelf ↔ bool
getter/setter pair
isValidateVoteMessage ↔ bool
getter/setter pair
isVoted ↔ bool
getter/setter pair
isVoting ↔ bool
getter/setter pair
messageExts ↔ List<V2TimMessageExtension>
getter/setter pair
msg ↔ V2TimMessage
getter/setter pair
optionsBox ↔ Map<int, bool>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voteData ↔ TencentCloudChatVoteData
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOptionsBox(int index) → dynamic
setGroupMemberCount(int count) → dynamic
setIsClose(bool close) → dynamic
setIsFold(bool fold) → dynamic
setIsVoting(bool voting) → dynamic
setMessageExt(List<V2TimMessageExtension> msgExts) → dynamic
setOptionsBox(int index) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited